#define todo_width 16
#define todo_height 16
static char todo_bits[] = {
   0x00, 0x30, 0xff, 0xfb, 0xff, 0x7d, 0x03, 0x3c, 0x1b, 0x5e, 0x3b, 0x6f,
   0x3b, 0x6f, 0xbb, 0x67, 0xf3, 0x63, 0xf3, 0x63, 0xe3, 0x61, 0xe3, 0x60,
   0x63, 0x60, 0x03, 0x60, 0xff, 0x7f, 0xff, 0x7f};
